@@ -258,11 +258,14 @@ def fit_all_lm(basic, xlist, data, remove_na=True) -> dict:
     """
     # Prepare the data frame
     data = copy.deepcopy(data)
-    data = data[get_all_vars_from_formula(basic) + xlist]
+    data_cols = get_all_vars_from_formula(basic) + xlist
+    # make sure that no duplicates are present in the data_cols
+    data_cols = list(set(data_cols))
+    data = data[data_cols]
     if remove_na:
         data = data.dropna()
-    print(data.head())
-    # basic model
+    print(f"The basic model is: {basic}")
+    print(f"The following features will be used for fitting the basic model: {data.columns}")
     mod_0 = ols(basic, data=data).fit()
     p = mod_0.pvalues.iloc[1]
     print(f"p-values: {p}")
@@ -277,6 +280,12 @@ def fit_all_lm(basic, xlist, data, remove_na=True) -> dict:
 
     # All combinations model
     comb_lst = list(itertools.chain.from_iterable(itertools.combinations(xlist, r) for r in range(1, len(xlist) + 1)))
+    n_comb = len(comb_lst)
+    # if more than 100 combinations, exit
+    if n_comb > 100:
+        print(f"Number of combinations is {n_comb}. Exiting.")
+        return None
+    print(f"Combinations: {comb_lst}")
     models = [ols(f"{basic} + {' + '.join(comb)}", data=data).fit() for comb in comb_lst]
 
     df_list = []
@@ -294,7 +303,7 @@ def fit_all_lm(basic, xlist, data, remove_na=True) -> dict:
     return {"estimate": estimates, "xlist": xlist, "fun": "all_lm", "basic": basic, "family": "lm"}
 
 
-def plot_coeff_vs_pvals(data, xlabels=None, xlim=(0, 1), xlab="p-value", ylim=None, ylab=None, xscale_log=True, yscale_log=False, title=None, show=True) -> None:
+def plot_coeff_vs_pvals(data, xlabels=None, xlim=(0, 1), xlab="p-value", ylim=None, ylab=None, xscale_log=True, yscale_log=False, title=None, show=True, y_scaler=1.1) -> None:
     """Plot the coefficient estimates from fit_all_lm against the corresponding p-values.
 
     Args:
@@ -319,6 +328,8 @@ def plot_coeff_vs_pvals(data, xlabels=None, xlim=(0, 1), xlab="p-value", ylim=No
             The plot title.
         show (bool):
             Whether to display the plot.
+        y_scaler (float):
+            A scaling factor for the y-axis limits. Default is 1.1, i.e., 10% more than the maximum value.
 
     Returns:
         None
@@ -353,6 +364,7 @@ def plot_coeff_vs_pvals(data, xlabels=None, xlim=(0, 1), xlab="p-value", ylim=No
     result_df["p_value"] = np.power(result_df["p"], np.log(0.5) / np.log(0.05))
     if ylim is None:
         maxv = max(result_df["estimate"].max(), abs(result_df["estimate"].min()))
+        maxv = maxv * y_scaler
         ylim = (-maxv, maxv) if data["fun"] == "all_lm" else (1 / maxv, maxv)
 
     plt.figure(figsize=(10, 6))
@@ -375,7 +387,7 @@ def plot_coeff_vs_pvals(data, xlabels=None, xlim=(0, 1), xlab="p-value", ylim=No
         plt.show()
 
 
-def plot_coeff_vs_pvals_by_included(data, xlabels=None, xlim=(0, 1), xlab="P value", ylim=None, ylab=None, yscale_log=False, title=None, grid=True, ncol=2, show=True) -> None:
+def plot_coeff_vs_pvals_by_included(data, xlabels=None, xlim=(0, 1), xlab="P value", ylim=None, ylab=None, yscale_log=False, title=None, grid=True, ncol=2, show=True, y_scaler=1.1) -> None:
     """
     Generates a panel of scatter plots with effect estimates of all possible models against p-values.
     Uses a dictionry generated by the fit_all_lm function.
@@ -396,6 +408,8 @@ def plot_coeff_vs_pvals_by_included(data, xlabels=None, xlim=(0, 1), xlab="P val
         title (str): The title of the plot.
         grid (bool): Whether to display gridlines. Default is True.
         ncol (int): Number of columns in the plot grid. Default is 2.
+        show (bool): Whether to display the plot. Default is True.
+        y_scaler (float): A scaling factor for the y-axis limits. Default is 1.1, i.e., 10% more than the maximum value.
 
     Returns:
         None
@@ -436,6 +450,7 @@ def plot_coeff_vs_pvals_by_included(data, xlabels=None, xlim=(0, 1), xlab="P val
     result_df["p_value"] = np.power(result_df["p"], np.log(0.5) / np.log(0.05))
     if ylim is None:
         maxv = max(result_df["estimate"].max(), abs(result_df["estimate"].min()))
+        maxv = maxv * y_scaler
         if data["fun"] == "all_lm":
             ylim = (-maxv, maxv)
         else:
